Ortho4XP Tile Validator
=======================

This is a support utility for the Ortho4XP program, which creates scenery tiles
for the X-Plane Flight Simulation platform.

When run and pointed to the Ortho4XP directory, it will attempt to validate
all created tiles and report any errors.

It does not modify any files within the Ortho4XP directory.

Installation
____________
::

    $ pip install otv

This will install a script named **otv**, so if your PATH is setup correctly you
should be able to simply run ``otv`` from your system's command line.

